#include "TimerFrame.h"

IMPLEMENT_DYNAMIC_CLASS(TimerFrame, wxFrame)

TimerFrame::TimerFrame(wxWindow *parent, const wxString& title)
	: wxFrame(parent, -1, title, wxDefaultPosition, wxDefaultSize)
{
	
	// icon
	wxIcon *icon = new wxIcon();
	SetIcon(*icon);

	// get the current time
	wxString dt = MyTimeCtrl::GetCurrentTime();
	
	// controls
	wxPanel *panel = new wxPanel(this);
	wxStaticText *text = new wxStaticText(panel, -1, wxT("Set Time") );
	start = new wxButton(panel, ID_START, wxT("&Start") );
	stop = new wxButton(panel, ID_STOP, wxT("S&top") );
	choose = new wxButton(panel, ID_CHOOSE, wxT("Choose &File") );
	timectrl = new MyTimeCtrl(panel, -1, dt);
	
	// sizer
	wxBoxSizer *box = new wxBoxSizer(wxHORIZONTAL);
	
	box->Add(text, 0, wxALIGN_CENTER | wxALL, 5);
	box->Add(timectrl, 0, wxALIGN_CENTER | wxALL, 5);
	box->Add(start, 0, wxALIGN_CENTER | wxALL, 5);
	box->Add(stop, 0, wxALIGN_CENTER | wxALL, 5);
	box->Add(choose, 0, wxALIGN_CENTER | wxALL, 5);
	
	// disable stop button
	stop->Enable(FALSE);
	
	// fitting
	panel->SetSizer(box);
	panel->Fit();
	
	// status bar
	CreateStatusBar(2);
	Fit();

	// sound player
	player = new SoundPlayer();
	
	// timer
	timer = new wxTimer();
	timer->SetOwner(this, ID_TIMER);
	timer->Start(1000);
}

BEGIN_EVENT_TABLE(TimerFrame, wxFrame)
	EVT_BUTTON(ID_START, TimerFrame::OnStart)
	EVT_BUTTON(ID_STOP, TimerFrame::OnStop)
	EVT_BUTTON(ID_CHOOSE, TimerFrame::OnChoose)
	EVT_TIMER(ID_TIMER, TimerFrame::OnTimer)
END_EVENT_TABLE()


TimerFrame::~TimerFrame()
{
	if (player != NULL)
	{
		delete player;
	}
	
	if (timer != NULL)
	{
		delete timer;
	}
}

void TimerFrame::OnStart(wxCommandEvent& event)
{
	if (fn.IsNull() || fn.IsEmpty() ) 
	{
		wxBell();		
        wxMessageBox(wxT("Please select a sound file before continuing."),
                     wxT("No sound file selected"), wxOK | wxICON_EXCLAMATION);
		return;
	}
	
	start->Enable(FALSE);
	choose->Enable(FALSE);
	stop->Enable(TRUE);
	
	running = TRUE;
}

void TimerFrame::OnStop(wxCommandEvent& event)
{
	start->Enable(TRUE);
	choose->Enable(TRUE);
	stop->Enable(FALSE);	
	
	if (player->IsPlaying() )
	{
		player->Stop();
	}
	
	running = FALSE;
}

void TimerFrame::OnChoose(wxCommandEvent& event)
{
	wxFileDialog dlg( (wxWindow*) NULL, wxT("Choose a sound file"), wxT(""), wxT(""), wxT("All files (*.*)|*.*|WAV files (*.wav) |*.wav|MP3 files (*.mp3)|*.mp3"), wxOPEN | wxFILE_MUST_EXIST);
	if (dlg.ShowModal() == wxID_OK)
	{
		fn = dlg.GetPath();
	}
	SetStatusText(fn, 0);
}

void TimerFrame::OnTimer(wxTimerEvent& event)
{
	wxDateTime ct = wxDateTime();
	wxDateTime st = wxDateTime();
	
	wxString text;

	wxString current = MyTimeCtrl::GetCurrentTime();
	
	if (ct.ParseTime(current) != NULL && st.ParseTime(timectrl->GetValue() ) != NULL)
	{
		if (ct.IsEqualTo(st) && running)
		{
			player->SetFilename(fn);
			player->Play();
			
			text = wxT("READY!");
		}
		else
		{
			text = wxT("Current Time: ") + current;
		}
	}
	else
	{
		text = wxT("Could not build time");
	}
	
	SetStatusText(text, 1);	
}

